@@ -21,12 +21,18 @@ class CodeInjector:
         self.namespace = namespace
         self.annotations = namespace.get("__annotations__", {})
 
-    def evaluate(self, expression: str):
-        """Evaluate expression within namespaces of class."""
+    def evaluate(self, expression: str) -> Any:
+        """Evaluate expression within namespaces of class.
+
+        If expression not valid, return unique object to force application miscompare.
+
+        """
         # pylint: disable=eval-used
         try:
             result = eval(expression, self.f_globals)
-        except (SyntaxError, ValueError, TypeError):
+        except KeyboardInterrupt:  # pragma: no cover pylint: disable=try-except-raise
+            raise
+        except Exception:  # pylint: disable=broad-except
             # typeerror: e.g. Optional[int]
             result = object()
 
@@ -51,10 +57,7 @@ class CodeInjector:
             else:
                 expression = repr(value)
 
-            try:
-                is_same = self.evaluate(expression) is value
-            except (NameError, SyntaxError):
-                is_same = False
+            is_same = self.evaluate(expression) is value
 
         return expression if is_same else alternative
 
