@@ -9,8 +9,8 @@ from .._getbytes import getbytes
 from ..data import Data
 from ..dump import Record
 from ..exceptions import InsufficientMemoryError
-from ._bitfield import BitField, bitfield
-from ._meta import BitFieldsMeta, ByteOrderHint
+from .bitfield import BitField, bitfield
+from .meta import BitFieldsMeta, ByteOrderHint
 
 BitField.__module__ = "plum.bitfields"
 bitfield.__module__ = "plum.bitfields"
