@@ -22,15 +22,18 @@ class EnumX(Transform):
 
     def __init__(
         self,
-        name: str,
         enum: Type[IntEnum],
         nbytes: int = 1,
         byteorder: ByteOrderHint = "little",
         *,
         signed: bool = False,
         strict: bool = True,
+        name: Optional[str] = None,
     ) -> None:
-        super().__init__(name)
+        if name is None:
+            name = f"{enum.__name__} (IntEnum)"
+
+        super().__init__(name, hint=enum.__name__)
 
         assert nbytes > 0
         assert byteorder in {"big", "little"}
