@@ -13,7 +13,7 @@ class TestUnpack:
     """Test unpack method variants."""
 
     buffer = b"\x00\x01\x02"
-    greedy = ArrayX("greedy", fmt=uint8)
+    greedy = ArrayX(name="greedy", fmt=uint8)
 
     def test_unpack(self):
         array, _offset = self.greedy.__unpack__(self.buffer, 0, dims=(2,))
