@@ -27,30 +27,30 @@ class TestConformance(Case):
         ),
         dump=Baseline(
             """
-            +---------+--------+-------------+-------------------+----------+
-            | Offset  | Access | Value       | Bytes             | Format   |
-            +---------+--------+-------------+-------------------+----------+
-            | 0       |        | 4608        | 00 12             | MyBits   |
-            |  [0:8]  | f1     | 0           | ........ 00000000 | int      |
-            |  [8:12] | f2     | Register.R0 | ....0010 ........ | Register |
-            |  [12]   | f3     | True        | ...1.... ........ | bool     |
-            |  [13]   | f4     | False       | ..0..... ........ | bool     |
-            +---------+--------+-------------+-------------------+----------+
+            +---------+--------+-------------+-------------------+--------------------+
+            | Offset  | Access | Value       | Bytes             | Format             |
+            +---------+--------+-------------+-------------------+--------------------+
+            | 0       |        | 4608        | 00 12             | MyBits (BitFields) |
+            |  [0:8]  | f1     | 0           | ........ 00000000 | int                |
+            |  [8:12] | f2     | Register.R0 | ....0010 ........ | Register           |
+            |  [12]   | f3     | True        | ...1.... ........ | bool               |
+            |  [13]   | f4     | False       | ..0..... ........ | bool               |
+            +---------+--------+-------------+-------------------+--------------------+
             """
         ),
         excess=Baseline(
             """
-            +---------+--------+----------------+-------------------+----------+
-            | Offset  | Access | Value          | Bytes             | Format   |
-            +---------+--------+----------------+-------------------+----------+
-            | 0       |        | 4608           | 00 12             | MyBits   |
-            |  [0:8]  | f1     | 0              | ........ 00000000 | int      |
-            |  [8:12] | f2     | Register.R0    | ....0010 ........ | Register |
-            |  [12]   | f3     | True           | ...1.... ........ | bool     |
-            |  [13]   | f4     | False          | ..0..... ........ | bool     |
-            +---------+--------+----------------+-------------------+----------+
-            | 2       |        | <excess bytes> | 99                |          |
-            +---------+--------+----------------+-------------------+----------+
+            +---------+--------+----------------+-------------------+--------------------+
+            | Offset  | Access | Value          | Bytes             | Format             |
+            +---------+--------+----------------+-------------------+--------------------+
+            | 0       |        | 4608           | 00 12             | MyBits (BitFields) |
+            |  [0:8]  | f1     | 0              | ........ 00000000 | int                |
+            |  [8:12] | f2     | Register.R0    | ....0010 ........ | Register           |
+            |  [12]   | f3     | True           | ...1.... ........ | bool               |
+            |  [13]   | f4     | False          | ..0..... ........ | bool               |
+            +---------+--------+----------------+-------------------+--------------------+
+            | 2       |        | <excess bytes> | 99                |                    |
+            +---------+--------+----------------+-------------------+--------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -59,15 +59,16 @@ class TestConformance(Case):
         ),
         shortage=Baseline(
             """
-            +--------+----------------------+-------+--------+
-            | Offset | Value                | Bytes | Format |
-            +--------+----------------------+-------+--------+
-            | 0      | <insufficient bytes> | 00    | MyBits |
-            +--------+----------------------+-------+--------+
+            +--------+----------------------+-------+--------------------+
+            | Offset | Value                | Bytes | Format             |
+            +--------+----------------------+-------+--------------------+
+            | 0      | <insufficient bytes> | 00    | MyBits (BitFields) |
+            +--------+----------------------+-------+--------------------+
 
             InsufficientMemoryError occurred during unpack operation:
 
-            1 too few bytes to unpack 'MyBits' (2 needed, only 1 available)
+            1 too few bytes to unpack MyBits (BitFields), 2 needed, only 1
+            available
             """
         ),
         implementation=Baseline(
