@@ -31,26 +31,26 @@ class TestConformance(Case):
         values=(Custom(m0=1, m1=2), [1, 2], (1, 2), dict(m0=1, m1=2)),
         dump=Baseline(
             """
-            +--------+--------+-------+-------+--------+
-            | Offset | Access | Value | Bytes | Format |
-            +--------+--------+-------+-------+--------+
-            |        |        |       |       | Custom |
-            | 0      | m0     | 1     | 01    | uint8  |
-            | 1      | m1     | 2     | 02 00 | uint16 |
-            +--------+--------+-------+-------+--------+
+            +--------+--------+-------+-------+--------------------+
+            | Offset | Access | Value | Bytes | Format             |
+            +--------+--------+-------+-------+--------------------+
+            |        |        |       |       | Custom (Structure) |
+            | 0      | m0     | 1     | 01    | uint8              |
+            | 1      | m1     | 2     | 02 00 | uint16             |
+            +--------+--------+-------+-------+--------------------+
             """
         ),
         excess=Baseline(
             """
-            +--------+--------+----------------+-------+--------+
-            | Offset | Access | Value          | Bytes | Format |
-            +--------+--------+----------------+-------+--------+
-            |        |        |                |       | Custom |
-            | 0      | m0     | 1              | 01    | uint8  |
-            | 1      | m1     | 2              | 02 00 | uint16 |
-            +--------+--------+----------------+-------+--------+
-            | 3      |        | <excess bytes> | 99    |        |
-            +--------+--------+----------------+-------+--------+
+            +--------+--------+----------------+-------+--------------------+
+            | Offset | Access | Value          | Bytes | Format             |
+            +--------+--------+----------------+-------+--------------------+
+            |        |        |                |       | Custom (Structure) |
+            | 0      | m0     | 1              | 01    | uint8              |
+            | 1      | m1     | 2              | 02 00 | uint16             |
+            +--------+--------+----------------+-------+--------------------+
+            | 3      |        | <excess bytes> | 99    |                    |
+            +--------+--------+----------------+-------+--------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -59,17 +59,17 @@ class TestConformance(Case):
         ),
         shortage=Baseline(
             """
-            +--------+--------+----------------------+-------+--------+
-            | Offset | Access | Value                | Bytes | Format |
-            +--------+--------+----------------------+-------+--------+
-            |        |        |                      |       | Custom |
-            | 0      | m0     | 1                    | 01    | uint8  |
-            | 1      | m1     | <insufficient bytes> | 02    | uint16 |
-            +--------+--------+----------------------+-------+--------+
+            +--------+--------+----------------------+-------+--------------------+
+            | Offset | Access | Value                | Bytes | Format             |
+            +--------+--------+----------------------+-------+--------------------+
+            |        |        |                      |       | Custom (Structure) |
+            | 0      | m0     | 1                    | 01    | uint8              |
+            | 1      | m1     | <insufficient bytes> | 02    | uint16             |
+            +--------+--------+----------------------+-------+--------------------+
 
             InsufficientMemoryError occurred during unpack operation:
 
-            1 too few bytes to unpack 'uint16' (2 needed, only 1 available)
+            1 too few bytes to unpack uint16, 2 needed, only 1 available
             """
         ),
         implementation=Baseline(
