@@ -13,11 +13,11 @@ from baseline import Baseline
 from plum.array import ArrayX
 from plum.conformance import Case, CaseData, wrap_message
 from plum.enum import EnumX
-from plum.littleendian import uint8, uint16
+from plum.littleendian import double, uint8, uint16
 from plum.structure import Structure, dimmed_member, member
 
-uint8array = ArrayX("uint8array", fmt=uint8)
-uint16array = ArrayX("uint16array", fmt=uint16)
+uint8array = ArrayX(name="uint8array", fmt=uint8)
+uint16array = ArrayX(name="uint16array", fmt=uint16)
 
 
 class DataType(IntEnum):
@@ -28,7 +28,9 @@ class DataType(IntEnum):
     UINT16 = 1
 
 
-datatype = EnumX("datatype", DataType, nbytes=1, byteorder="big", signed=False)
+datatype = EnumX(
+    name="datatype", enum=DataType, nbytes=1, byteorder="big", signed=False
+)
 
 
 array_map = {
@@ -69,36 +71,36 @@ class TestSimpleSingleDim(Case):
         ),
         dump=Baseline(
             """
-            +--------+----------+-------+-------+--------------+
-            | Offset | Access   | Value | Bytes | Format       |
-            +--------+----------+-------+-------+--------------+
-            |        |          |       |       | SampleStruct |
-            | 0      | data_len | 4     | 04    | uint8        |
-            |        | data     |       |       | uint8array   |
-            | 1      |   [0]    | 0     | 00    | uint8        |
-            | 2      |   [1]    | 1     | 01    | uint8        |
-            | 3      |   [2]    | 2     | 02    | uint8        |
-            | 4      |   [3]    | 3     | 03    | uint8        |
-            | 5      | bookend  | 119   | 77    | uint8        |
-            +--------+----------+-------+-------+--------------+
+            +--------+----------+-------+-------+--------------------------+
+            | Offset | Access   | Value | Bytes | Format                   |
+            +--------+----------+-------+-------+--------------------------+
+            |        |          |       |       | SampleStruct (Structure) |
+            | 0      | data_len | 4     | 04    | uint8                    |
+            |        | data     |       |       | uint8array               |
+            | 1      |   [0]    | 0     | 00    | uint8                    |
+            | 2      |   [1]    | 1     | 01    | uint8                    |
+            | 3      |   [2]    | 2     | 02    | uint8                    |
+            | 4      |   [3]    | 3     | 03    | uint8                    |
+            | 5      | bookend  | 119   | 77    | uint8                    |
+            +--------+----------+-------+-------+--------------------------+
             """
         ),
         excess=Baseline(
             """
-            +--------+----------+----------------+-------+--------------+
-            | Offset | Access   | Value          | Bytes | Format       |
-            +--------+----------+----------------+-------+--------------+
-            |        |          |                |       | SampleStruct |
-            | 0      | data_len | 4              | 04    | uint8        |
-            |        | data     |                |       | uint8array   |
-            | 1      |   [0]    | 0              | 00    | uint8        |
-            | 2      |   [1]    | 1              | 01    | uint8        |
-            | 3      |   [2]    | 2              | 02    | uint8        |
-            | 4      |   [3]    | 3              | 03    | uint8        |
-            | 5      | bookend  | 119            | 77    | uint8        |
-            +--------+----------+----------------+-------+--------------+
-            | 6      |          | <excess bytes> | 99    |              |
-            +--------+----------+----------------+-------+--------------+
+            +--------+----------+----------------+-------+--------------------------+
+            | Offset | Access   | Value          | Bytes | Format                   |
+            +--------+----------+----------------+-------+--------------------------+
+            |        |          |                |       | SampleStruct (Structure) |
+            | 0      | data_len | 4              | 04    | uint8                    |
+            |        | data     |                |       | uint8array               |
+            | 1      |   [0]    | 0              | 00    | uint8                    |
+            | 2      |   [1]    | 1              | 01    | uint8                    |
+            | 3      |   [2]    | 2              | 02    | uint8                    |
+            | 4      |   [3]    | 3              | 03    | uint8                    |
+            | 5      | bookend  | 119            | 77    | uint8                    |
+            +--------+----------+----------------+-------+--------------------------+
+            | 6      |          | <excess bytes> | 99    |                          |
+            +--------+----------+----------------+-------+--------------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -107,22 +109,22 @@ class TestSimpleSingleDim(Case):
         ),
         shortage=Baseline(
             """
-            +--------+----------+----------------------+-------+--------------+
-            | Offset | Access   | Value                | Bytes | Format       |
-            +--------+----------+----------------------+-------+--------------+
-            |        |          |                      |       | SampleStruct |
-            | 0      | data_len | 4                    | 04    | uint8        |
-            |        | data     |                      |       | uint8array   |
-            | 1      |   [0]    | 0                    | 00    | uint8        |
-            | 2      |   [1]    | 1                    | 01    | uint8        |
-            | 3      |   [2]    | 2                    | 02    | uint8        |
-            | 4      |   [3]    | 3                    | 03    | uint8        |
-            |        | bookend  | <insufficient bytes> |       | uint8        |
-            +--------+----------+----------------------+-------+--------------+
+            +--------+----------+----------------------+-------+--------------------------+
+            | Offset | Access   | Value                | Bytes | Format                   |
+            +--------+----------+----------------------+-------+--------------------------+
+            |        |          |                      |       | SampleStruct (Structure) |
+            | 0      | data_len | 4                    | 04    | uint8                    |
+            |        | data     |                      |       | uint8array               |
+            | 1      |   [0]    | 0                    | 00    | uint8                    |
+            | 2      |   [1]    | 1                    | 01    | uint8                    |
+            | 3      |   [2]    | 2                    | 02    | uint8                    |
+            | 4      |   [3]    | 3                    | 03    | uint8                    |
+            |        | bookend  | <insufficient bytes> |       | uint8                    |
+            +--------+----------+----------------------+-------+--------------------------+
 
             InsufficientMemoryError occurred during unpack operation:
 
-            1 too few bytes to unpack 'uint8' (1 needed, only 0 available)
+            1 too few bytes to unpack uint8, 1 needed, only 0 available
             """
         ),
         implementation=Baseline(
@@ -248,38 +250,38 @@ class TestTypeFactorySingleDim(Case):
         ),
         dump=Baseline(
             """
-            +--------+-----------+----------------+-------+--------------+
-            | Offset | Access    | Value          | Bytes | Format       |
-            +--------+-----------+----------------+-------+--------------+
-            |        |           |                |       | SampleStruct |
-            | 0      | data_type | DataType.UINT8 | 00    | datatype     |
-            | 1      | data_len  | 4              | 04    | uint8        |
-            |        | data      |                |       | uint8array   |
-            | 2      |   [0]     | 0              | 00    | uint8        |
-            | 3      |   [1]     | 1              | 01    | uint8        |
-            | 4      |   [2]     | 2              | 02    | uint8        |
-            | 5      |   [3]     | 3              | 03    | uint8        |
-            | 6      | bookend   | 119            | 77    | uint8        |
-            +--------+-----------+----------------+-------+--------------+
+            +--------+-----------+----------------+-------+--------------------------+
+            | Offset | Access    | Value          | Bytes | Format                   |
+            +--------+-----------+----------------+-------+--------------------------+
+            |        |           |                |       | SampleStruct (Structure) |
+            | 0      | data_type | DataType.UINT8 | 00    | datatype                 |
+            | 1      | data_len  | 4              | 04    | uint8                    |
+            |        | data      |                |       | uint8array               |
+            | 2      |   [0]     | 0              | 00    | uint8                    |
+            | 3      |   [1]     | 1              | 01    | uint8                    |
+            | 4      |   [2]     | 2              | 02    | uint8                    |
+            | 5      |   [3]     | 3              | 03    | uint8                    |
+            | 6      | bookend   | 119            | 77    | uint8                    |
+            +--------+-----------+----------------+-------+--------------------------+
             """
         ),
         excess=Baseline(
             """
-            +--------+-----------+----------------+-------+--------------+
-            | Offset | Access    | Value          | Bytes | Format       |
-            +--------+-----------+----------------+-------+--------------+
-            |        |           |                |       | SampleStruct |
-            | 0      | data_type | DataType.UINT8 | 00    | datatype     |
-            | 1      | data_len  | 4              | 04    | uint8        |
-            |        | data      |                |       | uint8array   |
-            | 2      |   [0]     | 0              | 00    | uint8        |
-            | 3      |   [1]     | 1              | 01    | uint8        |
-            | 4      |   [2]     | 2              | 02    | uint8        |
-            | 5      |   [3]     | 3              | 03    | uint8        |
-            | 6      | bookend   | 119            | 77    | uint8        |
-            +--------+-----------+----------------+-------+--------------+
-            | 7      |           | <excess bytes> | 99    |              |
-            +--------+-----------+----------------+-------+--------------+
+            +--------+-----------+----------------+-------+--------------------------+
+            | Offset | Access    | Value          | Bytes | Format                   |
+            +--------+-----------+----------------+-------+--------------------------+
+            |        |           |                |       | SampleStruct (Structure) |
+            | 0      | data_type | DataType.UINT8 | 00    | datatype                 |
+            | 1      | data_len  | 4              | 04    | uint8                    |
+            |        | data      |                |       | uint8array               |
+            | 2      |   [0]     | 0              | 00    | uint8                    |
+            | 3      |   [1]     | 1              | 01    | uint8                    |
+            | 4      |   [2]     | 2              | 02    | uint8                    |
+            | 5      |   [3]     | 3              | 03    | uint8                    |
+            | 6      | bookend   | 119            | 77    | uint8                    |
+            +--------+-----------+----------------+-------+--------------------------+
+            | 7      |           | <excess bytes> | 99    |                          |
+            +--------+-----------+----------------+-------+--------------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -288,23 +290,23 @@ class TestTypeFactorySingleDim(Case):
         ),
         shortage=Baseline(
             """
-            +--------+-----------+----------------------+-------+--------------+
-            | Offset | Access    | Value                | Bytes | Format       |
-            +--------+-----------+----------------------+-------+--------------+
-            |        |           |                      |       | SampleStruct |
-            | 0      | data_type | DataType.UINT8       | 00    | datatype     |
-            | 1      | data_len  | 4                    | 04    | uint8        |
-            |        | data      |                      |       | uint8array   |
-            | 2      |   [0]     | 0                    | 00    | uint8        |
-            | 3      |   [1]     | 1                    | 01    | uint8        |
-            | 4      |   [2]     | 2                    | 02    | uint8        |
-            | 5      |   [3]     | 3                    | 03    | uint8        |
-            |        | bookend   | <insufficient bytes> |       | uint8        |
-            +--------+-----------+----------------------+-------+--------------+
+            +--------+-----------+----------------------+-------+--------------------------+
+            | Offset | Access    | Value                | Bytes | Format                   |
+            +--------+-----------+----------------------+-------+--------------------------+
+            |        |           |                      |       | SampleStruct (Structure) |
+            | 0      | data_type | DataType.UINT8       | 00    | datatype                 |
+            | 1      | data_len  | 4                    | 04    | uint8                    |
+            |        | data      |                      |       | uint8array               |
+            | 2      |   [0]     | 0                    | 00    | uint8                    |
+            | 3      |   [1]     | 1                    | 01    | uint8                    |
+            | 4      |   [2]     | 2                    | 02    | uint8                    |
+            | 5      |   [3]     | 3                    | 03    | uint8                    |
+            |        | bookend   | <insufficient bytes> |       | uint8                    |
+            +--------+-----------+----------------------+-------+--------------------------+
 
             InsufficientMemoryError occurred during unpack operation:
 
-            1 too few bytes to unpack 'uint8' (1 needed, only 0 available)
+            1 too few bytes to unpack uint8, 1 needed, only 0 available
             """
         ),
         implementation=Baseline(
@@ -467,7 +469,9 @@ class TestTypeFactoryMultiDim(Case):
     class MultiDimStruct(Structure):
 
         data_type: int = member(fmt=datatype, default=lambda parent: DataType.UINT8)
-        data_dims: list = member(fmt=ArrayX("dims", fmt=uint8, dims=(2,)), compute=True)
+        data_dims: list = member(
+            fmt=ArrayX(name="dims", fmt=uint8, dims=(2,)), compute=True
+        )
         data: list = dimmed_member(dims=data_dims, fmt=_get_array_cls)
         bookend: int = member(fmt=uint8)
 
@@ -487,46 +491,46 @@ class TestTypeFactoryMultiDim(Case):
         ),
         dump=Baseline(
             """
-            +--------+-----------+----------------+-------+----------------+
-            | Offset | Access    | Value          | Bytes | Format         |
-            +--------+-----------+----------------+-------+----------------+
-            |        |           |                |       | MultiDimStruct |
-            | 0      | data_type | DataType.UINT8 | 00    | datatype       |
-            |        | data_dims |                |       | dims           |
-            | 1      |   [0]     | 2              | 02    | uint8          |
-            | 2      |   [1]     | 2              | 02    | uint8          |
-            |        | data      |                |       | uint8array     |
-            |        |   [0]     |                |       |                |
-            | 3      |     [0]   | 0              | 00    | uint8          |
-            | 4      |     [1]   | 1              | 01    | uint8          |
-            |        |   [1]     |                |       |                |
-            | 5      |     [0]   | 2              | 02    | uint8          |
-            | 6      |     [1]   | 3              | 03    | uint8          |
-            | 7      | bookend   | 119            | 77    | uint8          |
-            +--------+-----------+----------------+-------+----------------+
+            +--------+-----------+----------------+-------+----------------------------+
+            | Offset | Access    | Value          | Bytes | Format                     |
+            +--------+-----------+----------------+-------+----------------------------+
+            |        |           |                |       | MultiDimStruct (Structure) |
+            | 0      | data_type | DataType.UINT8 | 00    | datatype                   |
+            |        | data_dims |                |       | dims                       |
+            | 1      |   [0]     | 2              | 02    | uint8                      |
+            | 2      |   [1]     | 2              | 02    | uint8                      |
+            |        | data      |                |       | uint8array                 |
+            |        |   [0]     |                |       |                            |
+            | 3      |     [0]   | 0              | 00    | uint8                      |
+            | 4      |     [1]   | 1              | 01    | uint8                      |
+            |        |   [1]     |                |       |                            |
+            | 5      |     [0]   | 2              | 02    | uint8                      |
+            | 6      |     [1]   | 3              | 03    | uint8                      |
+            | 7      | bookend   | 119            | 77    | uint8                      |
+            +--------+-----------+----------------+-------+----------------------------+
             """
         ),
         excess=Baseline(
             """
-            +--------+-----------+----------------+-------+----------------+
-            | Offset | Access    | Value          | Bytes | Format         |
-            +--------+-----------+----------------+-------+----------------+
-            |        |           |                |       | MultiDimStruct |
-            | 0      | data_type | DataType.UINT8 | 00    | datatype       |
-            |        | data_dims |                |       | dims           |
-            | 1      |   [0]     | 2              | 02    | uint8          |
-            | 2      |   [1]     | 2              | 02    | uint8          |
-            |        | data      |                |       | uint8array     |
-            |        |   [0]     |                |       |                |
-            | 3      |     [0]   | 0              | 00    | uint8          |
-            | 4      |     [1]   | 1              | 01    | uint8          |
-            |        |   [1]     |                |       |                |
-            | 5      |     [0]   | 2              | 02    | uint8          |
-            | 6      |     [1]   | 3              | 03    | uint8          |
-            | 7      | bookend   | 119            | 77    | uint8          |
-            +--------+-----------+----------------+-------+----------------+
-            | 8      |           | <excess bytes> | 99    |                |
-            +--------+-----------+----------------+-------+----------------+
+            +--------+-----------+----------------+-------+----------------------------+
+            | Offset | Access    | Value          | Bytes | Format                     |
+            +--------+-----------+----------------+-------+----------------------------+
+            |        |           |                |       | MultiDimStruct (Structure) |
+            | 0      | data_type | DataType.UINT8 | 00    | datatype                   |
+            |        | data_dims |                |       | dims                       |
+            | 1      |   [0]     | 2              | 02    | uint8                      |
+            | 2      |   [1]     | 2              | 02    | uint8                      |
+            |        | data      |                |       | uint8array                 |
+            |        |   [0]     |                |       |                            |
+            | 3      |     [0]   | 0              | 00    | uint8                      |
+            | 4      |     [1]   | 1              | 01    | uint8                      |
+            |        |   [1]     |                |       |                            |
+            | 5      |     [0]   | 2              | 02    | uint8                      |
+            | 6      |     [1]   | 3              | 03    | uint8                      |
+            | 7      | bookend   | 119            | 77    | uint8                      |
+            +--------+-----------+----------------+-------+----------------------------+
+            | 8      |           | <excess bytes> | 99    |                            |
+            +--------+-----------+----------------+-------+----------------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -535,27 +539,27 @@ class TestTypeFactoryMultiDim(Case):
         ),
         shortage=Baseline(
             """
-            +--------+-----------+----------------------+-------+----------------+
-            | Offset | Access    | Value                | Bytes | Format         |
-            +--------+-----------+----------------------+-------+----------------+
-            |        |           |                      |       | MultiDimStruct |
-            | 0      | data_type | DataType.UINT8       | 00    | datatype       |
-            |        | data_dims |                      |       | dims           |
-            | 1      |   [0]     | 2                    | 02    | uint8          |
-            | 2      |   [1]     | 2                    | 02    | uint8          |
-            |        | data      |                      |       | uint8array     |
-            |        |   [0]     |                      |       |                |
-            | 3      |     [0]   | 0                    | 00    | uint8          |
-            | 4      |     [1]   | 1                    | 01    | uint8          |
-            |        |   [1]     |                      |       |                |
-            | 5      |     [0]   | 2                    | 02    | uint8          |
-            | 6      |     [1]   | 3                    | 03    | uint8          |
-            |        | bookend   | <insufficient bytes> |       | uint8          |
-            +--------+-----------+----------------------+-------+----------------+
+            +--------+-----------+----------------------+-------+----------------------------+
+            | Offset | Access    | Value                | Bytes | Format                     |
+            +--------+-----------+----------------------+-------+----------------------------+
+            |        |           |                      |       | MultiDimStruct (Structure) |
+            | 0      | data_type | DataType.UINT8       | 00    | datatype                   |
+            |        | data_dims |                      |       | dims                       |
+            | 1      |   [0]     | 2                    | 02    | uint8                      |
+            | 2      |   [1]     | 2                    | 02    | uint8                      |
+            |        | data      |                      |       | uint8array                 |
+            |        |   [0]     |                      |       |                            |
+            | 3      |     [0]   | 0                    | 00    | uint8                      |
+            | 4      |     [1]   | 1                    | 01    | uint8                      |
+            |        |   [1]     |                      |       |                            |
+            | 5      |     [0]   | 2                    | 02    | uint8                      |
+            | 6      |     [1]   | 3                    | 03    | uint8                      |
+            |        | bookend   | <insufficient bytes> |       | uint8                      |
+            +--------+-----------+----------------------+-------+----------------------------+
 
             InsufficientMemoryError occurred during unpack operation:
 
-            1 too few bytes to unpack 'uint8' (1 needed, only 0 available)
+            1 too few bytes to unpack uint8, 1 needed, only 0 available
             """
         ),
         implementation=Baseline(
@@ -736,21 +740,45 @@ class TestExceptions:
 
     """Test exception use cases."""
 
-    def test_bad_dims_member(self):
+    def test_dims_not_a_member(self):
         """Verify exception/message if dimmed_member() gets bad dims member."""
         with pytest.raises(TypeError) as trap:
-
-            class BadRef(Structure):  # pylint: disable=unused-variable
-
-                """Simple sized array with bad reference."""
-
-                count: int = member(fmt=uint8, compute=True)
-                array: list = dimmed_member(fmt=ArrayX("array", fmt=uint8), dims="junk")
-                bookend: uint8
+            dimmed_member(fmt=ArrayX(name="array", fmt=uint8), dims="junk")
 
         expected = Baseline(
             """
-            invalid 'dims', must be a 'member()'
+            invalid 'dims', must be a member() where 'fmt' is either an integer
+            transform or an array transform with a single dim and non-greedy
+            """
+        )
+
+        assert wrap_message(trap.value) == expected
+
+    def test_dims_fmt_not_intx_or_arrayx(self):
+        """Verify exception/message if dimmed_member() gets dims member with bad fmt."""
+        with pytest.raises(TypeError) as trap:
+            dims = member(fmt=double)
+            dimmed_member(fmt=ArrayX(name="array", fmt=uint8), dims=dims)
+
+        expected = Baseline(
+            """
+            invalid 'dims', must be a member() where 'fmt' is either an integer
+            transform or an array transform with a single dim and non-greedy
+            """
+        )
+
+        assert wrap_message(trap.value) == expected
+
+    def test_dims_fmt_bad_array(self):
+        """Verify exception/message if dimmed_member() gets dims member with bad fmt."""
+        with pytest.raises(TypeError) as trap:
+            dims = member(fmt=ArrayX(name="array", fmt=uint8, dims=(2, 2)))
+            dimmed_member(fmt=ArrayX(name="array", fmt=uint8), dims=dims)
+
+        expected = Baseline(
+            """
+            invalid 'dims', must be a member() where 'fmt' is either an integer
+            transform or an array transform with a single dim and non-greedy
             """
         )
 
@@ -779,7 +807,7 @@ class TestException:
     def test_dims_wrong_type(self):
         expected_message = Baseline(
             """
-            'dims' dims member not an integer or array transform format
+            invalid 'dims', must be a member() where 'fmt' is either an integer transform or an array transform with a single dim and non-greedy
             """
         )
 
