@@ -31,28 +31,28 @@ class TestFmtArg(Case):
         ),
         dump=Baseline(
             """
-            +--------+----------+-------+-------+--------+
-            | Offset | Access   | Value | Bytes | Format |
-            +--------+----------+-------+-------+--------+
-            |        |          |       |       | Struct |
-            | 0      | datatype | 0     | 00    | uint8  |
-            | 1      | data     | 1     | 01    | uint8  |
-            | 2      | bookend  | 119   | 77    | uint8  |
-            +--------+----------+-------+-------+--------+
+            +--------+----------+-------+-------+--------------------+
+            | Offset | Access   | Value | Bytes | Format             |
+            +--------+----------+-------+-------+--------------------+
+            |        |          |       |       | Struct (Structure) |
+            | 0      | datatype | 0     | 00    | uint8              |
+            | 1      | data     | 1     | 01    | uint8              |
+            | 2      | bookend  | 119   | 77    | uint8              |
+            +--------+----------+-------+-------+--------------------+
             """
         ),
         excess=Baseline(
             """
-            +--------+----------+----------------+-------+--------+
-            | Offset | Access   | Value          | Bytes | Format |
-            +--------+----------+----------------+-------+--------+
-            |        |          |                |       | Struct |
-            | 0      | datatype | 0              | 00    | uint8  |
-            | 1      | data     | 1              | 01    | uint8  |
-            | 2      | bookend  | 119            | 77    | uint8  |
-            +--------+----------+----------------+-------+--------+
-            | 3      |          | <excess bytes> | 99    |        |
-            +--------+----------+----------------+-------+--------+
+            +--------+----------+----------------+-------+--------------------+
+            | Offset | Access   | Value          | Bytes | Format             |
+            +--------+----------+----------------+-------+--------------------+
+            |        |          |                |       | Struct (Structure) |
+            | 0      | datatype | 0              | 00    | uint8              |
+            | 1      | data     | 1              | 01    | uint8              |
+            | 2      | bookend  | 119            | 77    | uint8              |
+            +--------+----------+----------------+-------+--------------------+
+            | 3      |          | <excess bytes> | 99    |                    |
+            +--------+----------+----------------+-------+--------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -61,18 +61,18 @@ class TestFmtArg(Case):
         ),
         shortage=Baseline(
             """
-            +--------+----------+----------------------+-------+--------+
-            | Offset | Access   | Value                | Bytes | Format |
-            +--------+----------+----------------------+-------+--------+
-            |        |          |                      |       | Struct |
-            | 0      | datatype | 0                    | 00    | uint8  |
-            | 1      | data     | 1                    | 01    | uint8  |
-            |        | bookend  | <insufficient bytes> |       | uint8  |
-            +--------+----------+----------------------+-------+--------+
+            +--------+----------+----------------------+-------+--------------------+
+            | Offset | Access   | Value                | Bytes | Format             |
+            +--------+----------+----------------------+-------+--------------------+
+            |        |          |                      |       | Struct (Structure) |
+            | 0      | datatype | 0                    | 00    | uint8              |
+            | 1      | data     | 1                    | 01    | uint8              |
+            |        | bookend  | <insufficient bytes> |       | uint8              |
+            +--------+----------+----------------------+-------+--------------------+
 
             InsufficientMemoryError occurred during unpack operation:
 
-            1 too few bytes to unpack 'uint8' (1 needed, only 0 available)
+            1 too few bytes to unpack uint8, 1 needed, only 0 available
             """
         ),
         implementation=Baseline(
@@ -201,28 +201,28 @@ class TestMethod(Case):
         ),
         dump=Baseline(
             """
-            +--------+----------+-------+-------+--------+
-            | Offset | Access   | Value | Bytes | Format |
-            +--------+----------+-------+-------+--------+
-            |        |          |       |       | Struct |
-            | 0      | datatype | 0     | 00    | uint8  |
-            | 1      | data     | 1     | 01    | uint8  |
-            | 2      | bookend  | 119   | 77    | uint8  |
-            +--------+----------+-------+-------+--------+
+            +--------+----------+-------+-------+--------------------+
+            | Offset | Access   | Value | Bytes | Format             |
+            +--------+----------+-------+-------+--------------------+
+            |        |          |       |       | Struct (Structure) |
+            | 0      | datatype | 0     | 00    | uint8              |
+            | 1      | data     | 1     | 01    | uint8              |
+            | 2      | bookend  | 119   | 77    | uint8              |
+            +--------+----------+-------+-------+--------------------+
             """
         ),
         excess=Baseline(
             """
-            +--------+----------+----------------+-------+--------+
-            | Offset | Access   | Value          | Bytes | Format |
-            +--------+----------+----------------+-------+--------+
-            |        |          |                |       | Struct |
-            | 0      | datatype | 0              | 00    | uint8  |
-            | 1      | data     | 1              | 01    | uint8  |
-            | 2      | bookend  | 119            | 77    | uint8  |
-            +--------+----------+----------------+-------+--------+
-            | 3      |          | <excess bytes> | 99    |        |
-            +--------+----------+----------------+-------+--------+
+            +--------+----------+----------------+-------+--------------------+
+            | Offset | Access   | Value          | Bytes | Format             |
+            +--------+----------+----------------+-------+--------------------+
+            |        |          |                |       | Struct (Structure) |
+            | 0      | datatype | 0              | 00    | uint8              |
+            | 1      | data     | 1              | 01    | uint8              |
+            | 2      | bookend  | 119            | 77    | uint8              |
+            +--------+----------+----------------+-------+--------------------+
+            | 3      |          | <excess bytes> | 99    |                    |
+            +--------+----------+----------------+-------+--------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -231,18 +231,18 @@ class TestMethod(Case):
         ),
         shortage=Baseline(
             """
-            +--------+----------+----------------------+-------+--------+
-            | Offset | Access   | Value                | Bytes | Format |
-            +--------+----------+----------------------+-------+--------+
-            |        |          |                      |       | Struct |
-            | 0      | datatype | 0                    | 00    | uint8  |
-            | 1      | data     | 1                    | 01    | uint8  |
-            |        | bookend  | <insufficient bytes> |       | uint8  |
-            +--------+----------+----------------------+-------+--------+
+            +--------+----------+----------------------+-------+--------------------+
+            | Offset | Access   | Value                | Bytes | Format             |
+            +--------+----------+----------------------+-------+--------------------+
+            |        |          |                      |       | Struct (Structure) |
+            | 0      | datatype | 0                    | 00    | uint8              |
+            | 1      | data     | 1                    | 01    | uint8              |
+            |        | bookend  | <insufficient bytes> |       | uint8              |
+            +--------+----------+----------------------+-------+--------------------+
 
             InsufficientMemoryError occurred during unpack operation:
 
-            1 too few bytes to unpack 'uint8' (1 needed, only 0 available)
+            1 too few bytes to unpack uint8, 1 needed, only 0 available
             """
         ),
         implementation=Baseline(
@@ -377,28 +377,28 @@ class TestProperty(Case):
         ),
         dump=Baseline(
             """
-            +--------+----------+-------+-------+--------+
-            | Offset | Access   | Value | Bytes | Format |
-            +--------+----------+-------+-------+--------+
-            |        |          |       |       | Struct |
-            | 0      | datatype | 0     | 00    | uint8  |
-            | 1      | data     | 1     | 01    | uint8  |
-            | 2      | bookend  | 119   | 77    | uint8  |
-            +--------+----------+-------+-------+--------+
+            +--------+----------+-------+-------+--------------------+
+            | Offset | Access   | Value | Bytes | Format             |
+            +--------+----------+-------+-------+--------------------+
+            |        |          |       |       | Struct (Structure) |
+            | 0      | datatype | 0     | 00    | uint8              |
+            | 1      | data     | 1     | 01    | uint8              |
+            | 2      | bookend  | 119   | 77    | uint8              |
+            +--------+----------+-------+-------+--------------------+
             """
         ),
         excess=Baseline(
             """
-            +--------+----------+----------------+-------+--------+
-            | Offset | Access   | Value          | Bytes | Format |
-            +--------+----------+----------------+-------+--------+
-            |        |          |                |       | Struct |
-            | 0      | datatype | 0              | 00    | uint8  |
-            | 1      | data     | 1              | 01    | uint8  |
-            | 2      | bookend  | 119            | 77    | uint8  |
-            +--------+----------+----------------+-------+--------+
-            | 3      |          | <excess bytes> | 99    |        |
-            +--------+----------+----------------+-------+--------+
+            +--------+----------+----------------+-------+--------------------+
+            | Offset | Access   | Value          | Bytes | Format             |
+            +--------+----------+----------------+-------+--------------------+
+            |        |          |                |       | Struct (Structure) |
+            | 0      | datatype | 0              | 00    | uint8              |
+            | 1      | data     | 1              | 01    | uint8              |
+            | 2      | bookend  | 119            | 77    | uint8              |
+            +--------+----------+----------------+-------+--------------------+
+            | 3      |          | <excess bytes> | 99    |                    |
+            +--------+----------+----------------+-------+--------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -407,18 +407,18 @@ class TestProperty(Case):
         ),
         shortage=Baseline(
             """
-            +--------+----------+----------------------+-------+--------+
-            | Offset | Access   | Value                | Bytes | Format |
-            +--------+----------+----------------------+-------+--------+
-            |        |          |                      |       | Struct |
-            | 0      | datatype | 0                    | 00    | uint8  |
-            | 1      | data     | 1                    | 01    | uint8  |
-            |        | bookend  | <insufficient bytes> |       | uint8  |
-            +--------+----------+----------------------+-------+--------+
+            +--------+----------+----------------------+-------+--------------------+
+            | Offset | Access   | Value                | Bytes | Format             |
+            +--------+----------+----------------------+-------+--------------------+
+            |        |          |                      |       | Struct (Structure) |
+            | 0      | datatype | 0                    | 00    | uint8              |
+            | 1      | data     | 1                    | 01    | uint8              |
+            |        | bookend  | <insufficient bytes> |       | uint8              |
+            +--------+----------+----------------------+-------+--------------------+
 
             InsufficientMemoryError occurred during unpack operation:
 
-            1 too few bytes to unpack 'uint8' (1 needed, only 0 available)
+            1 too few bytes to unpack uint8, 1 needed, only 0 available
             """
         ),
         implementation=Baseline(
