@@ -35,26 +35,26 @@ class TestNested(Case):
         ),
         dump=Baseline(
             """
-            +--------+---------+-------+-------+--------+
-            | Offset | Access  | Value | Bytes | Format |
-            +--------+---------+-------+-------+--------+
-            |        |         |       |       | Outer  |
-            |        | outer   |       |       | Nested |
-            | 0      |   inner | 0     | 00    | uint8  |
-            +--------+---------+-------+-------+--------+
+            +--------+---------+-------+-------+--------------------+
+            | Offset | Access  | Value | Bytes | Format             |
+            +--------+---------+-------+-------+--------------------+
+            |        |         |       |       | Outer (Structure)  |
+            |        | outer   |       |       | Nested (Structure) |
+            | 0      |   inner | 0     | 00    | uint8              |
+            +--------+---------+-------+-------+--------------------+
             """
         ),
         excess=Baseline(
             """
-            +--------+---------+----------------+-------+--------+
-            | Offset | Access  | Value          | Bytes | Format |
-            +--------+---------+----------------+-------+--------+
-            |        |         |                |       | Outer  |
-            |        | outer   |                |       | Nested |
-            | 0      |   inner | 0              | 00    | uint8  |
-            +--------+---------+----------------+-------+--------+
-            | 1      |         | <excess bytes> | 99    |        |
-            +--------+---------+----------------+-------+--------+
+            +--------+---------+----------------+-------+--------------------+
+            | Offset | Access  | Value          | Bytes | Format             |
+            +--------+---------+----------------+-------+--------------------+
+            |        |         |                |       | Outer (Structure)  |
+            |        | outer   |                |       | Nested (Structure) |
+            | 0      |   inner | 0              | 00    | uint8              |
+            +--------+---------+----------------+-------+--------------------+
+            | 1      |         | <excess bytes> | 99    |                    |
+            +--------+---------+----------------+-------+--------------------+
 
             ExcessMemoryError occurred during unpack operation:
 
@@ -63,17 +63,17 @@ class TestNested(Case):
         ),
         shortage=Baseline(
             """
-            +--------+---------+----------------------+-------+--------+
-            | Offset | Access  | Value                | Bytes | Format |
-            +--------+---------+----------------------+-------+--------+
-            |        |         |                      |       | Outer  |
-            |        | outer   |                      |       | Nested |
-            |        |   inner | <insufficient bytes> |       | uint8  |
-            +--------+---------+----------------------+-------+--------+
+            +--------+---------+----------------------+-------+--------------------+
+            | Offset | Access  | Value                | Bytes | Format             |
+            +--------+---------+----------------------+-------+--------------------+
+            |        |         |                      |       | Outer (Structure)  |
+            |        | outer   |                      |       | Nested (Structure) |
+            |        |   inner | <insufficient bytes> |       | uint8              |
+            +--------+---------+----------------------+-------+--------------------+
 
             InsufficientMemoryError occurred during unpack operation:
 
-            1 too few bytes to unpack 'uint8' (1 needed, only 0 available)
+            1 too few bytes to unpack uint8, 1 needed, only 0 available
             """
         ),
         implementation=Baseline(
